# -*- coding: iso-8859-1 -*-
from __future__ import print_function
from Plugins.Plugin import PluginDescriptor
from Components.config import config, ConfigSubsection, ConfigSelection
from Screens.Standby import Standby, inStandby
from Screens.MessageBox import MessageBox
from StartupToIdleConfiguration import StartupToIdleConfiguration, version_txt
from Tools.DreamboxHardware import getFPWakeuptime, getFPWasTimerWakeup
from Tools import Notifications
from os import path as os_path, remove as os_remove
from time import localtime, strftime

config.plugins.startuptoidle = ConfigSubsection()
startuptoidle_option = []
startuptoidle_option.append(("no", _("no")))
startuptoidle_option.append(("always", _("always")))
startuptoidle_option.append(("crashOnIdle", _("only on restart after 'power cut' or 'crash on idle mode'")))
config.plugins.startuptoidle.enabled = ConfigSelection(choices = startuptoidle_option, default = "no")

startupToIdleCheckFile = "/etc/enigma2/.StartupToIdleCheck"

def main(session, **kwargs):
	print("[StartupToIdle] Open Config Screen")
	session.open(StartupToIdleConfiguration)

# autostart
def autostart(reason, **kwargs):
	if reason == 1:
		if os_path.exists(startupToIdleCheckFile):
			print("[StartupToIdle] shutdown - remove idleCheck-file")
			os_remove(startupToIdleCheckFile)
		else:
			print("[StartupToIdle] shutdown - nothing to do")

def getRTCtime():
	rtc_time = ""
	if os_path.exists("/proc/stb/fp/rtc"):
		rtc_time = int(open("/proc/stb/fp/rtc","r").read()) # exist only on OE2.6
	return rtc_time

# sessionstart
def sessionstart(reason, **kwargs):
	if kwargs.has_key("session") and reason == 0:
		config.misc.standbyCounter.addNotifier(onIdle, initial_call=False)
	enabledAllways = config.plugins.startuptoidle.enabled.value == "allways"
	enabledOnCrash = config.plugins.startuptoidle.enabled.value == "crashOnIdle" and os_path.exists(startupToIdleCheckFile)
	
	#check for powercut - works only on OE2.6
	rtc_time = getRTCtime()
	print("[StartupToIdle] sessionstart - rtc: '%s'" % (rtc_time))
	wakeup_time = getFPWakeuptime()
	print("[StartupToIdle] sessionstart - wakeuptime: %s = %s" % (wakeup_time, strftime("%d.%m.%Y %H:%M:%S", localtime(float(wakeup_time)))))
	was_timer_wakeup = getFPWasTimerWakeup()
	print("[StartupToIdle] sessionstart - was_timer_wakeup: %s" % (was_timer_wakeup))
	enabledAfterPowerCut = config.plugins.startuptoidle.enabled.value == "crashOnIdle" and rtc_time == 0 and wakeup_time == 0 and was_timer_wakeup == False
	
	print("[StartupToIdle] sessionstart - allways: %s, onCrash: %s, afterPowerCut: %s" % (enabledAllways, enabledOnCrash, enabledAfterPowerCut))
	
	if (enabledAllways or enabledOnCrash or enabledAfterPowerCut) and reason == 0 and not inStandby:
		print("[StartupToIdle] sessionstart - going to idle")
		Notifications.AddNotificationWithID("Standby", Standby)
		
		#show message
		if rtc_time == "" and enabledOnCrash: #message for power cut or crash on OE2.5
			print("[StartupToIdle] sessionstart - show message")
			message = _("StartupToIdle\n\nThe box was set to idle mode after a power cut or a green screen (crash) on last idle mode.\n\nA possible crashlog-file you can find in '/media/hdd/'.")
			Notifications.AddPopup(message, MessageBox.TYPE_INFO, 30)
		elif enabledAfterPowerCut:
			print("[StartupToIdle] sessionstart - show message")
			message = _("StartupToIdle\n\nThe box was set to idle mode on restart after a power cut.")
			Notifications.AddPopup(message, MessageBox.TYPE_INFO, 30)
		elif enabledOnCrash:
			print("[StartupToIdle] sessionstart - show message")
			message = _("StartupToIdle\n\nThe box was set to idle mode after a green screen (crash) on last idle mode.\n\nA possible crashlog-file you can find in '/media/hdd/'.")
			Notifications.AddPopup(message, MessageBox.TYPE_INFO, 30)
	
	elif os_path.exists(startupToIdleCheckFile):
		print("[StartupToIdle] sessionstart - don't going to idle - remove idleCheck-file")
		os_remove(startupToIdleCheckFile)
	else:
		print("[StartupToIdle] sessionstart - don't going to idle")

def onIdle(configElement):
	from Screens.Standby import inStandby
	inStandby.onClose.append(onLeaveIdle)
	if config.plugins.startuptoidle.enabled.value == "crashOnIdle":
		print("[StartupToIdle] onIdle - create idleCheck-file")
		open(startupToIdleCheckFile,"a").close()
	else:
		print("[StartupToIdle] onIdle - nothing to do")

def onLeaveIdle():
	if os_path.exists(startupToIdleCheckFile):
		print("[StartupToIdle] onLeaveIdle - remove idleCheck-file")
		os_remove(startupToIdleCheckFile)
	else:
		print("[StartupToIdle] onLeaveIdle - nothing to do")

def Plugins(path, **kwargs):
	pname = "StartupToIdle" + " v" + version_txt
	pdesc = "Startup To Idle Mode"
	return [
	PluginDescriptor(name=pname, description = pdesc, where = PluginDescriptor.WHERE_PLUGINMENU, fnc = main, needsRestart = False, icon = "plugin.png"),
	PluginDescriptor(name=pname, description = pdesc, where = PluginDescriptor.WHERE_SESSIONSTART, fnc = sessionstart, needsRestart = False, weight = -1),
	PluginDescriptor(name=pname, where = PluginDescriptor.WHERE_AUTOSTART, fnc = autostart)
	]

